@@ -5,9 +5,10 @@ use warnings;
 
 use parent qw{ Exporter };
 
-use vars qw{ @EXPORT_OK };
+use vars qw{ @EXPORT_OK @EXPORT };
 
-@EXPORT_OK = qw{ process_file post pre process filter next_line };
+@EXPORT    = qw{ process_file };
+@EXPORT_OK = qw{ post pre process filter next_line };
 
 use Carp;
 use Carp::Always;
@@ -23,7 +24,7 @@ Readonly my $FALSE   => 0;
 Readonly my $EMPTY   => q{};
 Readonly my $NL      => "\n";
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our %DEFAULT_PROCESSORS = (
   pre       => \&_pre,
@@ -338,6 +339,8 @@ File::Process - process text files with customer handlers
 
 =head1 SYNOPSIS
 
+ use File::Process;
+
  my ($lines, $info) = process_file($file, process => sub { 
      my ($fh, $lines, $args, $line) = @_;
      return uc($line);
@@ -374,6 +377,8 @@ processors.
 
 =head1 METHODS AND SUBROUTINES
 
+By default, only C<process_file> is exported.
+
 =head2 process_file(file, options)
 
 You start the processing of the file by calling C<process_file> with
@@ -553,9 +558,9 @@ anything it wants.
 
 =head1 DEFAULT PROCESSORS
 
-Any of default processors (B<pre>, B<next_line>, B<process>, B<post>)
-can be called before or after your custom processors.  Pass these
-methods the same list you receive.
+Any of default processors (B<pre>, B<next_line>, B<filter>,
+B<process>, B<post>) can be called before or after your custom
+processors.  Pass these methods the same list you receive.
 
   process_file(
     "foo.txt",
